@@ -3,7 +3,6 @@ use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
 pub use checkout_server_derive::Server;
-use uuid::Uuid;
 
 use crate::context::{Context, ContextProvider};
 use crate::customer::{Address, Contact};
@@ -12,7 +11,7 @@ use crate::money::Currency;
 
 #[derive(Serialize, Deserialize, JsonSchema)]
 pub struct StandardPathParams {
-    pub id: Uuid,
+    pub id: String,
 }
 
 #[derive(Serialize, Deserialize, JsonSchema)]
